/*
 * Access a filesystem.
 *
 * Copyright (C) 2019, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdio.h>
#include <unistd.h>

#include "ops.h"
#include "session.h"



/* Help message. */

char help_text[] = "\
Usage: %s [ <options> ] <operation> <filename>...\n\
\n\
File permission options:\n\
\n\
  -m MASK       Set mode/permissions mask for new directories\n\
\n\
Transfer operations:\n\
\n\
  copy-in       Copy files into a directory within the image\n\
  copy-out      Copy files from the image into a directory\n\
\n\
Image operations:\n\
\n\
  ls            List files and directories within the image\n\
  mkdir         Make directories within the image\n\
  rm            Remove non-directory objects from the image\n\
  rmdir         Remove directories from the image\n\
  stat          Show statistics for files and directories\n\
\n\
Script operations:\n\
\n\
  script        Read operations from a script file\n\
";

/* Operations exposed by the program. */

struct operation operations[] = {
    {"copy-in", copy_in},
#if 0
    {"copy-out", copy_out},
#endif
    {"ls", list_objects},
    {"mkdir", make_dirs},
#if 0
    {"rm", remove_non_dirs},
    {"rmdir", remove_dirs},
#endif
    {"script", run_script},
    {"stat", stat_objects},
    {NULL, NULL},
    };

/* Main program. */

int main(int argc, char *argv[])
{
    /* Program argument details. */

    char **args;
    int num_args;
    enum op_results op_result;

    /* Parse program options and initialise the argument details. */

    if (parse_options(argc, argv))
        return 1;

    args = &argv[optind];
    num_args = argc - optind;

    if (num_args < 2)
    {
        fprintf(stderr, help_text, argv[0]);
        return 1;
    }

    /* Perform the requested operation. */

    op_result = run_operation(args[0], num_args - 1, &args[1]);
    return handle_op_result(args[0], op_result);
}

/* vim: tabstop=4 expandtab shiftwidth=4
*/
